pub enum AsyncCompressReader<R> {
None(BufReader<R>),
Zstd(Box<AsyncZstdSeekableReader<'static, BufReader<R>>>),
}Variants
Implementations
Sourceimpl<R: AsyncRead + AsyncSeek + Unpin> AsyncCompressReader<R>
impl<R: AsyncRead + AsyncSeek + Unpin> AsyncCompressReader<R>
Sourcepub async fn new(inner: R) -> Result<Self>
pub async fn new(inner: R) -> Result<Self>
Create a new AsyncCompressReader from a reader
It will detect the compression type using magic bytes and return the appropriate reader.
Note: The reader will be return to the start after detecting the compression type.
pub fn compress_type(&self) -> CompressType