pub enum CompressReader {
None(BufReader<File>),
Zstd(Box<ZstdReader<'static, BufReader<File>>>),
}Expand description
A reader that can read compressed files
Variants
Implementations
Sourceimpl CompressReader
impl CompressReader
Sourcepub fn new(inner: File) -> Result<Self>
pub fn new(inner: File) -> Result<Self>
Create a new CompressReader from a File
It will detect the compression type using magic bytes and return the appropriate reader.
Note: The reader will be return to the original position after detecting the compression type.
pub fn file_size(&self) -> Result<usize>
pub fn compress_type(&self) -> CompressType